@@ -8,7 +8,6 @@ import optparse
 import os
 import platform
 import re
-import signal
 import socket
 import subprocess
 import sys
@@ -41,50 +40,6 @@ import monasca_agent.common.config as configuration
 from monasca_agent.common.exceptions import PathNotFound
 
 
-class Watchdog(object):
-
-    """Simple signal-based watchdog that will scuttle the current process
-    if it has not been reset every N seconds, or if the processes exceeds
-    a specified memory threshold.
-    Can only be invoked once per process, so don't use with multiple threads.
-    If you instantiate more than one, you're also asking for trouble.
-    """
-
-    def __init__(self, duration, max_mem_mb=None):
-        import resource
-
-        # Set the duration
-        self._duration = int(duration)
-        signal.signal(signal.SIGALRM, Watchdog.self_destruct)
-
-        # cap memory usage
-        if max_mem_mb is not None:
-            self._max_mem_kb = 1024 * max_mem_mb
-            max_mem_bytes = 1024 * self._max_mem_kb
-            resource.setrlimit(resource.RLIMIT_AS, (max_mem_bytes, max_mem_bytes))
-            self.memory_limit_enabled = True
-        else:
-            self.memory_limit_enabled = False
-
-    @staticmethod
-    def self_destruct(signum, frame):
-        try:
-            import traceback
-            log.error("Self-destructing...")
-            log.error(traceback.format_exc())
-        finally:
-            os.kill(os.getpid(), signal.SIGKILL)
-
-    def reset(self):
-        # self destruct if using too much memory, as tornado will swallow MemoryErrors
-        mem_usage_kb = int(os.popen('ps -p %d -o %s | tail -1' % (os.getpid(), 'rss')).read())
-        if self.memory_limit_enabled and mem_usage_kb > (0.95 * self._max_mem_kb):
-            Watchdog.self_destruct(signal.SIGKILL, sys._getframe(0))
-
-        log.debug("Resetting watchdog for %d" % self._duration)
-        signal.alarm(self._duration)
-
-
 class PidFile(object):
     """A small helper class for pidfiles. """
 
