@@ -7,11 +7,10 @@ log = logging.getLogger(__name__)
 
 
 class ArgsPlugin(Plugin):
-    """ Base plugin for detection plugins that take arguments for configuration rather than do detection."""
+    """Base plugin for detection plugins that take arguments for configuration rather than do detection."""
 
     def _build_instance(self, arg_list):
-        """ If a value for each arg in the arg_list was specified build it into an instance dictionary. Also check
-            for dimensions and add if they were specified.
+        """If a value for each arg in the arg_list was specified build it into an instance dictionary. Also check for dimensions and add if they were specified.
         :param arg_list: Arguments to include
         :return: instance dictionary
         """
@@ -24,7 +23,7 @@ class ArgsPlugin(Plugin):
         return instance
 
     def _check_required_args(self, arg_list):
-        """ Check that the required args were specified
+        """Check that the required args were specified
         :param arg_list: A list of arguments to verify were specified
         :return: True if the required args exist false otherwise
         """
