@@ -1,13 +1,13 @@
 import logging
 import psutil
-from urlparse import urlparse
+import urlparse
 
 from plugin import Plugin
 
 from monasca_setup import agent_config
-from monasca_setup.detection import find_process_cmdline
-from monasca_setup.detection import service_api_check
-from monasca_setup.detection import watch_process
+from monasca_setup.detection.utils import find_process_cmdline
+from monasca_setup.detection.utils import service_api_check
+from monasca_setup.detection.utils import watch_process
 
 
 log = logging.getLogger(__name__)
@@ -58,24 +58,26 @@ class ServicePlugin(Plugin):
 
         if self.service_api_url and self.search_pattern:
             # Check if there is something listening on the host/port
-            parsed = urlparse(self.service_api_url)
+            parsed = urlparse.urlparse(self.service_api_url)
             host, port = parsed.netloc.split(':')
             listening = []
             for connection in psutil.net_connections():
-               if connection.status == psutil.CONN_LISTEN and connection.laddr[1] == int(port):
-                   listening.append(connection.laddr[0])
+                if connection.status == psutil.CONN_LISTEN and connection.laddr[1] == int(port):
+                    listening.append(connection.laddr[0])
 
             if len(listening) > 0:
                 # If not listening on localhost or ips then use another local ip
-                if host == 'localhost' and len(set(['0.0.0.0', '::', '::1']) & set(listening)) == 0:
-                    api_url = listening[0] + ':' + port
+                if host == 'localhost' and len(set(['127.0.0.1', '0.0.0.0', '::', '::1']) & set(listening)) == 0:
+                    new_url = list(parsed)
+                    new_url[1] = listening[0] + ':' + port
+                    api_url = urlparse.urlunparse(new_url)
                 else:
                     api_url = self.service_api_url
 
                 # Setup an active http_status check on the API
                 log.info("\tConfiguring an http_check for the {0} API.".format(self.service_name))
                 config.merge(service_api_check(self.service_name + '-api', api_url,
-                                           self.search_pattern, self.service_name))
+                                               self.search_pattern, self.service_name))
             else:
                 log.info("\tNo process found listening on {0} ".format(port) +
                          "skipping setup of http_check for the {0} API." .format(self.service_name))
